Module execution_tx

Module execution_tx 

Defines the ExecutionTxMap interface that models a collection of transmitters used to route can ExecutionRequest to the appropriate ExecutionManagers.

Structs

MultiExchangeTxMap
A map of exchange transmitters that efficiently routes execution requests to exchange-specific transmitter channels.

Traits

ExecutionTxMap
Collection of ExecutionRequest Txs for each exchange ExecutionManager.