Module logging

Module logging 

Opinionated default tracing subscriber for downstream services that don’t already own one.

Skippable — if the host service has already installed a tracing_subscriber, calling init_tracing is a no-op (the try_init call returns an error, which we deliberately swallow).

Functions

init_tracing
Install a default tracing subscriber.