pub struct MultiExchangeTxMap<Tx = UnboundedTx<ExecutionRequest>>(/* private fields */);Expand description
A map of exchange transmitters that efficiently routes execution requests to exchange-specific transmitter channels.
FnvIndexMap of ExecutionRequest Txs for each exchange.
Facilitates the routing of execution requests in a multi exchange trading system.
Note that a transmitter for an exchange is optional. This handles the case where instruments for an exchange may be tracked by the trading system, but not trading on.
Without this optional transmitter the ExchangeIndexs would not be valid..